pickle_to_part

Function pickle_to_part 

pub fn pickle_to_part(py: Python<'_>, obj: &Py<PyAny>) -> PyResult<Part>
Pickle a Python object and return the serialized data as a Part.

This is a simplified variant of pickle that disallows pending pickles and tensor engine references, and returns the raw serialized bytes instead of a PicklingState.