pub struct PendingMessage { /* private fields */ }Expand description
A message that is pending resolution of async values before it can be sent.
Contains a PythonMessageKind and a PicklingState. The PicklingState may contain
pending pickles (unresolved async values) that must be resolved before the message
can be converted into a PythonMessage.
Implementations
Sourceimpl PendingMessage
impl PendingMessage
Sourcepub fn new(kind: PythonMessageKind, state: PicklingState) -> Self
pub fn new(kind: PythonMessageKind, state: PicklingState) -> Self
Create a new PendingMessage from a kind and pickling state.
Sourcepub fn take(&mut self) -> PyResult<PendingMessage>
pub fn take(&mut self) -> PyResult<PendingMessage>
Take ownership of the inner state from a mutable reference.
This is used by pyo3 pymethods that receive &mut PendingMessage
but need to pass ownership to the trait method.
Sourcepub async fn resolve(self) -> PyResult<PythonMessage>
pub async fn resolve(self) -> PyResult<PythonMessage>
Resolve all pending pickles and convert this into a PythonMessage.
This is an async method that:
- Awaits all pending pickles in the PicklingState
- Re-pickles the resolved object
- Returns a PythonMessage with the resolved bytes (no GIL needed for final step)
Sourceimpl PendingMessage
impl PendingMessage
Sourcepub fn py_new(
kind: PythonMessageKind,
state: PyRefMut<'_, PicklingState>,
) -> PyResult<Self>
pub fn py_new( kind: PythonMessageKind, state: PyRefMut<'_, PicklingState>, ) -> PyResult<Self>
Create a new PendingMessage from a kind and pickling state.