pub struct PicklingState { /* private fields */ }Expand description
Python-visible wrapper for the result of a pickling operation.
Contains the pickled bytes and any tensor engine references or pending pickles that were collected during serialization.
Implementations
Sourceimpl PicklingState
impl PicklingState
pub fn take_inner(&mut self) -> PyResult<PicklingStateInner>
Sourceimpl PicklingState
impl PicklingState
Sourcepub async fn resolve(self) -> PyResult<PicklingState>
pub async fn resolve(self) -> PyResult<PicklingState>
Resolve all pending pickles and return a new PicklingState without pending pickles.
This consumes the PicklingState. It:
- If there are no pending pickles, returns self immediately
- Otherwise, awaits all pending pickles until they’re finished
- Calls unpickle to reconstruct the object
- Calls pickle again to get a new PicklingState without pending pickles