pub fn push_pending_pickle(py_shared: Py<PyShared>) -> PyResult<()>Expand description
Push a pending pickle to the active pickling state (Rust-only).
This is used by reduce implementations to register a PyShared that must be resolved before the pickle is complete.
Returns an error if there is no active pickling state or if pending pickles are not allowed in the current pickling context.